Module auditor

Module auditor 

Code for an auditor of a authenticated key directory

Functions

audit_verify
Verifies an audit proof, given start and end hashes for a merkle patricia tree.
verify_consecutive_append_only
Helper for audit, verifies an append-only proof.