pub enum HistoryVerificationParams {
Default {
history_params: HistoryParams,
},
AllowMissingValues {
history_params: HistoryParams,
},
}Expand description
Parameters for customizing how history proof verification proceeds
Variants
Default
No customization to the verification procedure
Fields

history_params: HistoryParamsthe HistoryParams that was used to generate the history proof
AllowMissingValues
Allows for the encountering of missing (tombstoned) values instead of attempting to check if their hash matches the leaf node hash
Fields

history_params: HistoryParamsthe HistoryParams that was used to generate the history proof