Module verify

Module verify 

This module contains verification calls for different proofs contained in the AKD crate

Modules

base
Base functionality for verification operations (membership, non-membership, etc)
history
Verification of key history proofs
lookup
Verification of lookup proofs

Enums

HistoryVerificationParams
Parameters for customizing how history proof verification proceeds
VerificationError
Proof verification error types

Functions

key_history_verify
Verifies a key history proof, given the corresponding sequence of hashes. Returns a vector of whether the validity of a hash could be verified. When false, the value <=> hash validity at the position could not be verified because the value has been removed (“tombstoned”) from the storage layer.
lookup_verify
Verifies a lookup with respect to the root_hash