Code for an auditor of a authenticated key directory
Functions
- audit_
verify - Verifies an audit proof, given start and end hashes for a merkle patricia tree.
- verify_
consecutive_ append_ only - Helper for audit, verifies an append-only proof.