Enum akd::errors::HistoryTreeNodeError [−][src]
pub enum HistoryTreeNodeError {
Show 16 variants
NoDirectionInSettingChild(u64, u64),
DirectionIsNone,
NoChildInTreeAtEpoch(u64, usize),
NoChildrenInTreeAtEpoch(u64),
InvalidEpochForUpdatingHash(u64),
TriedToUpdateParentOfRoot,
ParentNextEpochInvalid(u64),
HashUpdateOnlyAllowedAfterNodeInsertion,
TriedToHashLeafChildren,
NodeCreatedWithoutEpochs(u64),
LeafNodeLabelLenLessThanInterior(NodeLabel),
CompressionError(NodeLabel),
NodeDidNotExistAtEp(NodeLabel, u64),
NodeDidNotHaveExistingStateAtEp(NodeLabel, u64),
StorageError(StorageError),
SerializationError,
}Expand description
Errors thown by HistoryTreeNodes
Variants
NoDirectionInSettingChild(u64, u64)
Tried to set a child and the direction given was none.
DirectionIsNone
Direction is unexpectedly None
NoChildInTreeAtEpoch(u64, usize)
The node didn’t have a child in the given epoch
NoChildrenInTreeAtEpoch(u64)
Tuple Fields
0: u64The node had no children at the given epoch
InvalidEpochForUpdatingHash(u64)
Tuple Fields
0: u64The hash was being updated for an invalid epoch
TriedToUpdateParentOfRoot
Tried to update the parent of the root, which should not be done
ParentNextEpochInvalid(u64)
Tuple Fields
0: u64The next epoch of this node’s parent was invalid
HashUpdateOnlyAllowedAfterNodeInsertion
The hash of a parent was attempted to be updated, without setting the calling node as a child.
TriedToHashLeafChildren
The children of a leaf are always dummy and should not be hashed
NodeCreatedWithoutEpochs(u64)
Tuple Fields
0: u64The list of epochs for a given node was empty
LeafNodeLabelLenLessThanInterior(NodeLabel)
Tuple Fields
0: NodeLabelThe label of a leaf node was shorter than that of an interior node.
CompressionError(NodeLabel)
Tuple Fields
0: NodeLabelError compressing the Merkle trie
NodeDidNotExistAtEp(NodeLabel, u64)
Tried to access something about the node at an epoch that didn’t exist.
NodeDidNotHaveExistingStateAtEp(NodeLabel, u64)
The state of a node did not exist at a given epoch
StorageError(StorageError)
Tuple Fields
0: StorageErrorError propogation
SerializationError
Error propogation