pub trait DomainLabel: Clone + 'static {
// Required method
fn domain_label() -> &'static [u8] ⓘ;
}Expand description
Trait for specifying a domain separation label that should be specific to the application
Required Methods
Sourcefn domain_label() -> &'static [u8] ⓘ
fn domain_label() -> &'static [u8] ⓘ
Returns a label, which is used as a domain separator when computing hashes
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".